@@ -340,7 +340,8 @@ show_hide_icon ()
 
 			xkl_debug (150, "Creating new icon\n");
 			icon = matekbd_status_new ();
-			gtk_status_icon_set_name (icon, "keyboard");
+                        /* commenting out fixes a Gdk-critical warning */
+/*			gtk_status_icon_set_name (icon, "keyboard");*/
 			g_signal_connect (icon, "popup-menu",
 					  G_CALLBACK
 					  (status_icon_popup_menu_cb),
