@@ -144,7 +144,7 @@ mp_name_vanished (GDBusConnection *connection,
     player_name = get_player_name(name);
 
     player_list = g_queue_find_custom (manager->priv->media_player_queue,
-                                       player_name, g_strcmp0);
+                                       player_name, (GCompareFunc) g_strcmp0);
 
     if (player_list)
         g_queue_remove (manager->priv->media_player_queue, player_list->data);
@@ -333,8 +333,8 @@ msd_mpris_manager_start (MsdMprisManager   *manager,
         g_bus_watch_name(G_BUS_TYPE_SESSION,
                          BUS_NAMES[i],
                          flags,
-                         mp_name_appeared,
-                         mp_name_vanished,
+                         (GBusNameAppearedCallback) mp_name_appeared,
+                         (GBusNameVanishedCallback) mp_name_vanished,
                          manager,
                          NULL);
     }
